@@ -1,6 +1,6 @@
 package Plack::Middleware::Negotiate;
 {
-  $Plack::Middleware::Negotiate::VERSION = '0.03';
+  $Plack::Middleware::Negotiate::VERSION = '0.04';
 }
 #ABSTRACT: Apply HTTP content negotiation as Plack middleware
 use strict;
@@ -32,6 +32,10 @@ sub prepare_app {
                 unless $self->{formats}->{$_}->{type};
         }
     }
+
+    $self->app( sub {
+        [ 406, ['Content-Type'=>'text/plain'], ['Not Acceptable']];
+    } ) unless $self->app;
 }
 
 sub call {
@@ -42,7 +46,9 @@ sub call {
     my $format = $self->negotiate($env);
     $env->{'negotiate.format'} = $format;
 
-    my $app = $self->{formats}->{$format}->{app} // $self->app;
+    my $app;
+    $app = $self->{formats}->{$format}->{app} if $format and $self->{formats}->{$format};
+    $app //= $self->app;
 
     Plack::Util::response_cb( $app->($env), sub {
         my $res = shift;
@@ -142,7 +148,7 @@ Plack::Middleware::Negotiate - Apply HTTP content negotiation as Plack middlewar
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -158,7 +164,7 @@ version 0.03
             },
             parameter => 'format', # e.g. http://example.org/foo?format=xml
             extension => 'strip';  # e.g. http://example.org/foo.xml
-        $app;
+        $app; # neither html nor xml requested
     };
 
 =head1 DESCRIPTION
@@ -171,6 +177,9 @@ care for rewriting and restoring PATH_INFO if it is configured to detect and
 strip a format extension. The PSGI response is enriched with corresponding HTTP
 headers Content-Type and Content-Language unless these headers already exist.
 
+If used as pure application, this middleware returns a HTTP status code 406 if
+no format could be negotiated.
+
 =head1 METHODS
 
 =head2 new ( formats => { ... } [ %argument ] )
